==> mailcommon-23.04.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim5MailCommon/KPim5MailCommonConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMailCommonConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MailCommon" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Akonadi "5.23.2")
find_dependency(KPim5AkonadiMime "5.23.2")
find_dependency(KPim5Libkdepim "5.23.2")
find_dependency(KPim5MessageComposer "5.23.2")
find_dependency(KF5PimCommon "5.23.2")
find_dependency(KF5Completion "5.103.0")

if (FALSE)
    message(WARNING "\n"
                    "************* DEPRECATION WARNING *************\n"
		    "Using find_package(KF5MailCommon) and KF5::MailCommon targets is deprecated. "
		    "Please use find_package(KPim5MailCommon) and KPim5::MailCommon instead. This backwards "
                    "compatibility will be removed in the next major version.\n"
                    "***********************************************\n")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/KPim5MailCommonTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KPim5MailCommonQchTargets.cmake")

==> mailcommon-23.08.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim5MailCommon/KPim5MailCommonConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMailCommonConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MailCommon" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Akonadi "5.24.0")
find_dependency(KPim5AkonadiMime "5.24.0")
find_dependency(KPim5Libkdepim "5.24.0")
find_dependency(KPim5MessageComposer "5.24.0")
find_dependency(KPim5PimCommon "5.24.0")
find_dependency(KPim5PimCommonAkonadi "5.24.0")
find_dependency(KF5Completion "5.105.0")

if (FALSE)
    message(WARNING "\n"
                    "************* DEPRECATION WARNING *************\n"
		    "Using find_package(KF5MailCommon) and KF5::MailCommon targets is deprecated. "
		    "Please use find_package(KPim5MailCommon) and KPim5::MailCommon instead. This backwards "
                    "compatibility will be removed in the next major version.\n"
                    "***********************************************\n")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/KPim5MailCommonTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KPim5MailCommonQchTargets.cmake")
